reduce nohz_full syscall overhead by 10%
Get series with b4
b4 am [email protected]Versions newest first
- v1 Latest3 patches 79 repliesIn review
Patches in v1 No applies recorded yet
| # | Subject and files | Size | Replies | Applied |
|---|---|---|---|---|
| 1/3 | reduce indentation in __acct_update_integralskernel/ | +17 | 0 replies | |
| 2/3 | remove local_irq_save from __acct_update_integralsarch/ arch/ include/ +2 more | +23 | 0 replies | |
| 3/3 | context_tracking,x86: remove extraneous irq disable & enable from context tracking on syscall entryarch/ arch/ arch/ +1 more | +20 | 79 replies |
Reviews trailers per patch
No Reviewed-by, Acked-by or Tested-by trailers for v1 yet.
Cover letter [PATCH 0/3] reduce nohz_full syscall overhead by 10%
Profiling reveals that a lot of the overhead from the nohz_full accounting seems to come not from the accounting itself, but from disabling and re-enabling interrupts.
This patch series removes the interrupt disabling & re-enabling from __acct_update_integrals, which is called on both syscall entry and exit, as well as from the user_exit called on syscall entry.
Together they speed up a benchmark that calls getpriority in a row 10 million times by about 10%:
run time system time
vanilla 5.49s 2.08s__acct patch 5.21s 1.92s
both patches 4.88s 1.71s